# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Event.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import Entry_pb2 as rst_dot_calendar_dot_Entry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Event.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x18rst/calendar/Event.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x18rst/calendar/Entry.proto\"\xd6\x02\n\x05\x45vent\x12\"\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x13.rst.calendar.Entry\x12@\n\x0c\x65vent_status\x18\x02 \x01(\x0e\x32\x1f.rst.calendar.Event.EventStatus:\tCONFIRMED\x12>\n\x0ctransparency\x18\x03 \x01(\x0e\x32 .rst.calendar.Event.Transparency:\x06OPAQUE\x12-\n\rend_date_time\x18\x04 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x10\n\x08\x64uration\x18\x05 \x01(\x12\"9\n\x0b\x45ventStatus\x12\r\n\tTENTATIVE\x10\x01\x12\r\n\tCONFIRMED\x10\x02\x12\x0c\n\x08\x43\x41NCELED\x10\x03\"+\n\x0cTransparency\x12\x0f\n\x0bTRANSPARENT\x10\x01\x12\n\n\x06OPAQUE\x10\x02\x42\x0b\x42\tEventType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_Entry__pb2.DESCRIPTOR,])



_EVENT_EVENTSTATUS = _descriptor.EnumDescriptor(
  name='EventStatus',
  full_name='rst.calendar.Event.EventStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TENTATIVE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFIRMED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=338,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_EVENT_EVENTSTATUS)

_EVENT_TRANSPARENCY = _descriptor.EnumDescriptor(
  name='Transparency',
  full_name='rst.calendar.Event.Transparency',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSPARENT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPAQUE', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=397,
  serialized_end=440,
)
_sym_db.RegisterEnumDescriptor(_EVENT_TRANSPARENCY)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='rst.calendar.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='rst.calendar.Event.entry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_status', full_name='rst.calendar.Event.event_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transparency', full_name='rst.calendar.Event.transparency', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='rst.calendar.Event.end_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.calendar.Event.duration', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENT_EVENTSTATUS,
    _EVENT_TRANSPARENCY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=440,
)

_EVENT.fields_by_name['entry'].message_type = rst_dot_calendar_dot_Entry__pb2._ENTRY
_EVENT.fields_by_name['event_status'].enum_type = _EVENT_EVENTSTATUS
_EVENT.fields_by_name['transparency'].enum_type = _EVENT_TRANSPARENCY
_EVENT.fields_by_name['end_date_time'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_EVENT_EVENTSTATUS.containing_type = _EVENT
_EVENT_TRANSPARENCY.containing_type = _EVENT
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), dict(
  DESCRIPTOR = _EVENT,
  __module__ = 'rst.calendar.Event_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Event)
  ))
_sym_db.RegisterMessage(Event)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tEventType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/CameraPose.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/CameraPose.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/geometry/CameraPose.proto\x12\x0crst.geometry\x1a\x17rst/geometry/Pose.proto\"\x82\x02\n\nCameraPose\x12V\n\x10\x63oordinate_frame\x18\x01 \x01(\x0e\x32(.rst.geometry.CameraPose.CoordinateFrame:\x12\x43\x41MERA_IMAGE_FRAME\x12 \n\x04pose\x18\x02 \x02(\x0b\x32\x12.rst.geometry.Pose\"z\n\x0f\x43oordinateFrame\x12\x16\n\x12\x43\x41MERA_IMAGE_FRAME\x10\x00\x12\x15\n\x11\x43\x41MERA_X_UP_FRAME\x10\x01\x12\x15\n\x11\x43\x41MERA_Y_UP_FRAME\x10\x02\x12\x0f\n\x0bLASER_FRAME\x10\x03\x12\x10\n\x0cSCREEN_FRAME\x10\x04\x42\x10\x42\x0e\x43\x61meraPoseType')
  ,
  dependencies=[rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,])



_CAMERAPOSE_COORDINATEFRAME = _descriptor.EnumDescriptor(
  name='CoordinateFrame',
  full_name='rst.geometry.CameraPose.CoordinateFrame',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAMERA_IMAGE_FRAME', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMERA_X_UP_FRAME', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMERA_Y_UP_FRAME', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LASER_FRAME', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCREEN_FRAME', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=209,
  serialized_end=331,
)
_sym_db.RegisterEnumDescriptor(_CAMERAPOSE_COORDINATEFRAME)


_CAMERAPOSE = _descriptor.Descriptor(
  name='CameraPose',
  full_name='rst.geometry.CameraPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinate_frame', full_name='rst.geometry.CameraPose.coordinate_frame', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='rst.geometry.CameraPose.pose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMERAPOSE_COORDINATEFRAME,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=331,
)

_CAMERAPOSE.fields_by_name['coordinate_frame'].enum_type = _CAMERAPOSE_COORDINATEFRAME
_CAMERAPOSE.fields_by_name['pose'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
_CAMERAPOSE_COORDINATEFRAME.containing_type = _CAMERAPOSE
DESCRIPTOR.message_types_by_name['CameraPose'] = _CAMERAPOSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CameraPose = _reflection.GeneratedProtocolMessageType('CameraPose', (_message.Message,), dict(
  DESCRIPTOR = _CAMERAPOSE,
  __module__ = 'rst.geometry.CameraPose_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.CameraPose)
  ))
_sym_db.RegisterMessage(CameraPose)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016CameraPoseType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/Legs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/Legs.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\x12rst/hri/Legs.proto\x12\x07rst.hri\"h\n\x04Legs\x12\r\n\x05\x61ngle\x18\x01 \x02(\x02\x12\x16\n\x0e\x61ngle_variance\x18\x02 \x02(\x02\x12\x10\n\x08\x64istance\x18\x03 \x02(\x02\x12\x19\n\x11\x64istance_variance\x18\x04 \x02(\x02\x12\x0c\n\x04pair\x18\x05 \x02(\x08\x42\nB\x08LegsType')
)




_LEGS = _descriptor.Descriptor(
  name='Legs',
  full_name='rst.hri.Legs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle', full_name='rst.hri.Legs.angle', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angle_variance', full_name='rst.hri.Legs.angle_variance', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='distance', full_name='rst.hri.Legs.distance', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='distance_variance', full_name='rst.hri.Legs.distance_variance', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pair', full_name='rst.hri.Legs.pair', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=135,
)

DESCRIPTOR.message_types_by_name['Legs'] = _LEGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Legs = _reflection.GeneratedProtocolMessageType('Legs', (_message.Message,), dict(
  DESCRIPTOR = _LEGS,
  __module__ = 'rst.hri.Legs_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.Legs)
  ))
_sym_db.RegisterMessage(Legs)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010LegsType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/NetworkState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/NetworkState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n&rst/devices/generic/NetworkState.proto\x12\x13rst.devices.generic\"\x9f\x08\n\x0cNetworkState\x12J\n\x04nics\x18\x01 \x03(\x0b\x32<.rst.devices.generic.NetworkState.NetworkInterfaceController\x12I\n\x0b\x63onnections\x18\x02 \x03(\x0b\x32\x34.rst.devices.generic.NetworkState.NetworkConnections\x1a\xde\x01\n\x1aNetworkInterfaceController\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\x16\n\x0e\x62ytes_received\x18\n \x01(\x04\x12\x12\n\nbytes_sent\x18\x0b \x01(\x04\x12\x18\n\x10packets_received\x18\x0c \x01(\x04\x12\x14\n\x0cpackets_sent\x18\r \x01(\x04\x12\x16\n\x0ereceive_errors\x18\x0e \x01(\x04\x12\x13\n\x0bsend_errors\x18\x0f \x01(\x04\x12\x15\n\rreceive_drops\x18\x10 \x01(\x04\x12\x12\n\nsend_drops\x18\x11 \x01(\x04\x1a\x96\x05\n\x12NetworkConnections\x12O\n\x08protocol\x18\x01 \x02(\x0e\x32=.rst.devices.generic.NetworkState.NetworkConnections.Protocol\x12R\n\x06\x66\x61mily\x18\x02 \x02(\x0e\x32\x42.rst.devices.generic.NetworkState.NetworkConnections.AddressFamily\x12\x17\n\x0fnum_established\x18\n \x01(\r\x12\x14\n\x0cnum_syn_sent\x18\x0b \x01(\r\x12\x14\n\x0cnum_syn_recv\x18\x0c \x01(\r\x12\x15\n\rnum_fin_wait1\x18\r \x01(\r\x12\x15\n\rnum_fin_wait2\x18\x0e \x01(\r\x12\x15\n\rnum_time_wait\x18\x0f \x01(\r\x12\x11\n\tnum_close\x18\x10 \x01(\r\x12\x16\n\x0enum_close_wait\x18\x11 \x01(\r\x12\x14\n\x0cnum_last_ack\x18\x12 \x01(\r\x12\x12\n\nnum_listen\x18\x13 \x01(\r\x12\x13\n\x0bnum_closing\x18\x14 \x01(\r\x12\x16\n\x0enum_delete_tcb\x18\x15 \x01(\r\x12\x10\n\x08num_idle\x18\x16 \x01(\r\x12\x11\n\tnum_bound\x18\x17 \x01(\r\x12\x10\n\x08num_none\x18( \x01(\r\"B\n\x08Protocol\x12\x10\n\x0cPROTOCOL_TCP\x10\x01\x12\x10\n\x0cPROTOCOL_UDP\x10\x02\x12\x12\n\x0ePROTOCOL_OTHER\x10\x64\"T\n\rAddressFamily\x12\x0f\n\x0b\x46\x41MILY_IPV4\x10\x01\x12\x0f\n\x0b\x46\x41MILY_IPV6\x10\x02\x12\x0f\n\x0b\x46\x41MILY_UNIX\x10\x03\x12\x10\n\x0c\x46\x41MILY_OTHER\x10\x64\x42\x12\x42\x10NetworkStateType')
)



_NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='rst.devices.generic.NetworkState.NetworkConnections.Protocol',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_TCP', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_UDP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_OTHER', index=2, number=100,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=967,
  serialized_end=1033,
)
_sym_db.RegisterEnumDescriptor(_NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL)

_NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY = _descriptor.EnumDescriptor(
  name='AddressFamily',
  full_name='rst.devices.generic.NetworkState.NetworkConnections.AddressFamily',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FAMILY_IPV4', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAMILY_IPV6', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAMILY_UNIX', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAMILY_OTHER', index=3, number=100,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1035,
  serialized_end=1119,
)
_sym_db.RegisterEnumDescriptor(_NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY)


_NETWORKSTATE_NETWORKINTERFACECONTROLLER = _descriptor.Descriptor(
  name='NetworkInterfaceController',
  full_name='rst.devices.generic.NetworkState.NetworkInterfaceController',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytes_received', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.bytes_received', index=1,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytes_sent', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.bytes_sent', index=2,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_received', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.packets_received', index=3,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_sent', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.packets_sent', index=4,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='receive_errors', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.receive_errors', index=5,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_errors', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.send_errors', index=6,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='receive_drops', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.receive_drops', index=7,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_drops', full_name='rst.devices.generic.NetworkState.NetworkInterfaceController.send_drops', index=8,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=454,
)

_NETWORKSTATE_NETWORKCONNECTIONS = _descriptor.Descriptor(
  name='NetworkConnections',
  full_name='rst.devices.generic.NetworkState.NetworkConnections',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='rst.devices.generic.NetworkState.NetworkConnections.protocol', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='family', full_name='rst.devices.generic.NetworkState.NetworkConnections.family', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_established', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_established', index=2,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_syn_sent', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_syn_sent', index=3,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_syn_recv', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_syn_recv', index=4,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_fin_wait1', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_fin_wait1', index=5,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_fin_wait2', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_fin_wait2', index=6,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_time_wait', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_time_wait', index=7,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_close', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_close', index=8,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_close_wait', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_close_wait', index=9,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_last_ack', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_last_ack', index=10,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_listen', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_listen', index=11,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_closing', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_closing', index=12,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_delete_tcb', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_delete_tcb', index=13,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_idle', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_idle', index=14,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_bound', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_bound', index=15,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_none', full_name='rst.devices.generic.NetworkState.NetworkConnections.num_none', index=16,
      number=40, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL,
    _NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=1119,
)

_NETWORKSTATE = _descriptor.Descriptor(
  name='NetworkState',
  full_name='rst.devices.generic.NetworkState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nics', full_name='rst.devices.generic.NetworkState.nics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='connections', full_name='rst.devices.generic.NetworkState.connections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_NETWORKSTATE_NETWORKINTERFACECONTROLLER, _NETWORKSTATE_NETWORKCONNECTIONS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=1119,
)

_NETWORKSTATE_NETWORKINTERFACECONTROLLER.containing_type = _NETWORKSTATE
_NETWORKSTATE_NETWORKCONNECTIONS.fields_by_name['protocol'].enum_type = _NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL
_NETWORKSTATE_NETWORKCONNECTIONS.fields_by_name['family'].enum_type = _NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY
_NETWORKSTATE_NETWORKCONNECTIONS.containing_type = _NETWORKSTATE
_NETWORKSTATE_NETWORKCONNECTIONS_PROTOCOL.containing_type = _NETWORKSTATE_NETWORKCONNECTIONS
_NETWORKSTATE_NETWORKCONNECTIONS_ADDRESSFAMILY.containing_type = _NETWORKSTATE_NETWORKCONNECTIONS
_NETWORKSTATE.fields_by_name['nics'].message_type = _NETWORKSTATE_NETWORKINTERFACECONTROLLER
_NETWORKSTATE.fields_by_name['connections'].message_type = _NETWORKSTATE_NETWORKCONNECTIONS
DESCRIPTOR.message_types_by_name['NetworkState'] = _NETWORKSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NetworkState = _reflection.GeneratedProtocolMessageType('NetworkState', (_message.Message,), dict(

  NetworkInterfaceController = _reflection.GeneratedProtocolMessageType('NetworkInterfaceController', (_message.Message,), dict(
    DESCRIPTOR = _NETWORKSTATE_NETWORKINTERFACECONTROLLER,
    __module__ = 'rst.devices.generic.NetworkState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.NetworkState.NetworkInterfaceController)
    ))
  ,

  NetworkConnections = _reflection.GeneratedProtocolMessageType('NetworkConnections', (_message.Message,), dict(
    DESCRIPTOR = _NETWORKSTATE_NETWORKCONNECTIONS,
    __module__ = 'rst.devices.generic.NetworkState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.NetworkState.NetworkConnections)
    ))
  ,
  DESCRIPTOR = _NETWORKSTATE,
  __module__ = 'rst.devices.generic.NetworkState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.NetworkState)
  ))
_sym_db.RegisterMessage(NetworkState)
_sym_db.RegisterMessage(NetworkState.NetworkInterfaceController)
_sym_db.RegisterMessage(NetworkState.NetworkConnections)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020NetworkStateType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/DateTime.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/DateTime.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/calendar/DateTime.proto\x12\x0crst.calendar\"\xad\x01\n\x08\x44\x61teTime\x12\x38\n\x0e\x64\x61te_time_type\x18\x01 \x01(\x0e\x32\x1b.rst.calendar.DateTime.Type:\x03UTC\x12\x18\n\x0btimezone_id\x18\x02 \x01(\t:\x03UTC\x12#\n\x18milliseconds_since_epoch\x18\x03 \x01(\x04:\x01\x30\"(\n\x04Type\x12\x07\n\x03UTC\x10\x01\x12\x0c\n\x08\x46LOATING\x10\x02\x12\t\n\x05LOCAL\x10\x03\x42\x0e\x42\x0c\x44\x61teTimeType')
)



_DATETIME_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.calendar.DateTime.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UTC', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOATING', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=179,
  serialized_end=219,
)
_sym_db.RegisterEnumDescriptor(_DATETIME_TYPE)


_DATETIME = _descriptor.Descriptor(
  name='DateTime',
  full_name='rst.calendar.DateTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date_time_type', full_name='rst.calendar.DateTime.date_time_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timezone_id', full_name='rst.calendar.DateTime.timezone_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("UTC").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='milliseconds_since_epoch', full_name='rst.calendar.DateTime.milliseconds_since_epoch', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATETIME_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=219,
)

_DATETIME.fields_by_name['date_time_type'].enum_type = _DATETIME_TYPE
_DATETIME_TYPE.containing_type = _DATETIME
DESCRIPTOR.message_types_by_name['DateTime'] = _DATETIME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DateTime = _reflection.GeneratedProtocolMessageType('DateTime', (_message.Message,), dict(
  DESCRIPTOR = _DATETIME,
  __module__ = 'rst.calendar.DateTime_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.DateTime)
  ))
_sym_db.RegisterMessage(DateTime)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014DateTimeType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/bayesnetwork/BayesVariable.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/bayesnetwork/BayesVariable.proto',
  package='rst.bayesnetwork',
  syntax='proto2',
  serialized_pb=_b('\n$rst/bayesnetwork/BayesVariable.proto\x12\x10rst.bayesnetwork\"\xd0\x01\n\rBayesVariable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.rst.bayesnetwork.BayesVariable.Type\x12\x10\n\x08outcomes\x18\x03 \x03(\t\x12\x10\n\x08property\x18\x04 \x03(\t\x12\x0f\n\x07parents\x18\x05 \x03(\t\x12\x19\n\rprobabilities\x18\x06 \x03(\x01\x42\x02\x10\x01\"-\n\x04Type\x12\n\n\x06NATURE\x10\x01\x12\x0c\n\x08\x44\x45\x43ISION\x10\x02\x12\x0b\n\x07UTILITY\x10\x03\x42\x13\x42\x11\x42\x61yesVariableType')
)



_BAYESVARIABLE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.bayesnetwork.BayesVariable.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NATURE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECISION', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UTILITY', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=222,
  serialized_end=267,
)
_sym_db.RegisterEnumDescriptor(_BAYESVARIABLE_TYPE)


_BAYESVARIABLE = _descriptor.Descriptor(
  name='BayesVariable',
  full_name='rst.bayesnetwork.BayesVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.bayesnetwork.BayesVariable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.bayesnetwork.BayesVariable.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outcomes', full_name='rst.bayesnetwork.BayesVariable.outcomes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='property', full_name='rst.bayesnetwork.BayesVariable.property', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parents', full_name='rst.bayesnetwork.BayesVariable.parents', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probabilities', full_name='rst.bayesnetwork.BayesVariable.probabilities', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BAYESVARIABLE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=267,
)

_BAYESVARIABLE.fields_by_name['type'].enum_type = _BAYESVARIABLE_TYPE
_BAYESVARIABLE_TYPE.containing_type = _BAYESVARIABLE
DESCRIPTOR.message_types_by_name['BayesVariable'] = _BAYESVARIABLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BayesVariable = _reflection.GeneratedProtocolMessageType('BayesVariable', (_message.Message,), dict(
  DESCRIPTOR = _BAYESVARIABLE,
  __module__ = 'rst.bayesnetwork.BayesVariable_pb2'
  # @@protoc_insertion_point(class_scope:rst.bayesnetwork.BayesVariable)
  ))
_sym_db.RegisterMessage(BayesVariable)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021BayesVariableType'))
_BAYESVARIABLE.fields_by_name['probabilities'].has_options = True
_BAYESVARIABLE.fields_by_name['probabilities']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/CalendarQueryResult.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import Event_pb2 as rst_dot_calendar_dot_Event__pb2
from rst.calendar import Todo_pb2 as rst_dot_calendar_dot_Todo__pb2
from rst.calendar import TimeZone_pb2 as rst_dot_calendar_dot_TimeZone__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/CalendarQueryResult.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n&rst/calendar/CalendarQueryResult.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x18rst/calendar/Event.proto\x1a\x17rst/calendar/Todo.proto\x1a\x1brst/calendar/TimeZone.proto\"\xee\x02\n\x13\x43\x61lendarQueryResult\x12(\n\x08timezone\x18\x01 \x03(\x0b\x32\x16.rst.calendar.TimeZone\x12?\n\x05\x65vent\x18\x02 \x03(\x0b\x32\x30.rst.calendar.CalendarQueryResult.EventWithTimes\x12 \n\x04todo\x18\x03 \x03(\x0b\x32\x12.rst.calendar.Todo\x1aX\n\nTimePeriod\x12%\n\x05start\x18\x01 \x02(\x0b\x32\x16.rst.calendar.DateTime\x12#\n\x03\x65nd\x18\x02 \x02(\x0b\x32\x16.rst.calendar.DateTime\x1ap\n\x0e\x45ventWithTimes\x12\"\n\x05\x65vent\x18\x01 \x02(\x0b\x32\x13.rst.calendar.Event\x12:\n\x04time\x18\x02 \x03(\x0b\x32,.rst.calendar.CalendarQueryResult.TimePeriodB\x19\x42\x17\x43\x61lendarQueryResultType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_Event__pb2.DESCRIPTOR,rst_dot_calendar_dot_Todo__pb2.DESCRIPTOR,rst_dot_calendar_dot_TimeZone__pb2.DESCRIPTOR,])




_CALENDARQUERYRESULT_TIMEPERIOD = _descriptor.Descriptor(
  name='TimePeriod',
  full_name='rst.calendar.CalendarQueryResult.TimePeriod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='rst.calendar.CalendarQueryResult.TimePeriod.start', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='rst.calendar.CalendarQueryResult.TimePeriod.end', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=418,
)

_CALENDARQUERYRESULT_EVENTWITHTIMES = _descriptor.Descriptor(
  name='EventWithTimes',
  full_name='rst.calendar.CalendarQueryResult.EventWithTimes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='rst.calendar.CalendarQueryResult.EventWithTimes.event', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='rst.calendar.CalendarQueryResult.EventWithTimes.time', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=532,
)

_CALENDARQUERYRESULT = _descriptor.Descriptor(
  name='CalendarQueryResult',
  full_name='rst.calendar.CalendarQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timezone', full_name='rst.calendar.CalendarQueryResult.timezone', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event', full_name='rst.calendar.CalendarQueryResult.event', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='todo', full_name='rst.calendar.CalendarQueryResult.todo', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CALENDARQUERYRESULT_TIMEPERIOD, _CALENDARQUERYRESULT_EVENTWITHTIMES, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=532,
)

_CALENDARQUERYRESULT_TIMEPERIOD.fields_by_name['start'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_CALENDARQUERYRESULT_TIMEPERIOD.fields_by_name['end'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_CALENDARQUERYRESULT_TIMEPERIOD.containing_type = _CALENDARQUERYRESULT
_CALENDARQUERYRESULT_EVENTWITHTIMES.fields_by_name['event'].message_type = rst_dot_calendar_dot_Event__pb2._EVENT
_CALENDARQUERYRESULT_EVENTWITHTIMES.fields_by_name['time'].message_type = _CALENDARQUERYRESULT_TIMEPERIOD
_CALENDARQUERYRESULT_EVENTWITHTIMES.containing_type = _CALENDARQUERYRESULT
_CALENDARQUERYRESULT.fields_by_name['timezone'].message_type = rst_dot_calendar_dot_TimeZone__pb2._TIMEZONE
_CALENDARQUERYRESULT.fields_by_name['event'].message_type = _CALENDARQUERYRESULT_EVENTWITHTIMES
_CALENDARQUERYRESULT.fields_by_name['todo'].message_type = rst_dot_calendar_dot_Todo__pb2._TODO
DESCRIPTOR.message_types_by_name['CalendarQueryResult'] = _CALENDARQUERYRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CalendarQueryResult = _reflection.GeneratedProtocolMessageType('CalendarQueryResult', (_message.Message,), dict(

  TimePeriod = _reflection.GeneratedProtocolMessageType('TimePeriod', (_message.Message,), dict(
    DESCRIPTOR = _CALENDARQUERYRESULT_TIMEPERIOD,
    __module__ = 'rst.calendar.CalendarQueryResult_pb2'
    # @@protoc_insertion_point(class_scope:rst.calendar.CalendarQueryResult.TimePeriod)
    ))
  ,

  EventWithTimes = _reflection.GeneratedProtocolMessageType('EventWithTimes', (_message.Message,), dict(
    DESCRIPTOR = _CALENDARQUERYRESULT_EVENTWITHTIMES,
    __module__ = 'rst.calendar.CalendarQueryResult_pb2'
    # @@protoc_insertion_point(class_scope:rst.calendar.CalendarQueryResult.EventWithTimes)
    ))
  ,
  DESCRIPTOR = _CALENDARQUERYRESULT,
  __module__ = 'rst.calendar.CalendarQueryResult_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.CalendarQueryResult)
  ))
_sym_db.RegisterMessage(CalendarQueryResult)
_sym_db.RegisterMessage(CalendarQueryResult.TimePeriod)
_sym_db.RegisterMessage(CalendarQueryResult.EventWithTimes)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\027CalendarQueryResultType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/DialogAct.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.dialog import IncrementalUnit_pb2 as rst_dot_dialog_dot_IncrementalUnit__pb2
from rst.dialog import SpeechHypotheses_pb2 as rst_dot_dialog_dot_SpeechHypotheses__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/DialogAct.proto',
  package='rst.dialog',
  syntax='proto2',
  serialized_pb=_b('\n\x1arst/dialog/DialogAct.proto\x12\nrst.dialog\x1a rst/dialog/IncrementalUnit.proto\x1a!rst/dialog/SpeechHypotheses.proto\"\xc3\x02\n\tDialogAct\x12(\n\x04type\x18\x01 \x02(\x0e\x32\x1a.rst.dialog.DialogAct.Type\x12\x35\n\x10incremental_unit\x18\x02 \x02(\x0b\x32\x1b.rst.dialog.IncrementalUnit\x12\x37\n\x11speech_hypotheses\x18\x03 \x01(\x0b\x32\x1c.rst.dialog.SpeechHypotheses\"\x9b\x01\n\x04Type\x12\t\n\x05GREET\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\n\n\x06REJECT\x10\x02\x12\x0b\n\x07\x43ONFIRM\x10\x03\x12\n\n\x06NEGATE\x10\x04\x12\x10\n\x0cINFO_REQUEST\x10\x05\x12\x12\n\x0e\x41\x43TION_REQUEST\x10\x06\x12\r\n\tSTATEMENT\x10\x07\x12\n\n\x06\x41NSWER\x10\x08\x12\x0b\n\x07GOODBYE\x10\t\x12\t\n\x05OTHER\x10\x64\x42\x0f\x42\rDialogActType')
  ,
  dependencies=[rst_dot_dialog_dot_IncrementalUnit__pb2.DESCRIPTOR,rst_dot_dialog_dot_SpeechHypotheses__pb2.DESCRIPTOR,])



_DIALOGACT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.dialog.DialogAct.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GREET', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFIRM', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEGATE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO_REQUEST', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REQUEST', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATEMENT', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANSWER', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOODBYE', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=10, number=100,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=280,
  serialized_end=435,
)
_sym_db.RegisterEnumDescriptor(_DIALOGACT_TYPE)


_DIALOGACT = _descriptor.Descriptor(
  name='DialogAct',
  full_name='rst.dialog.DialogAct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.dialog.DialogAct.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='incremental_unit', full_name='rst.dialog.DialogAct.incremental_unit', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speech_hypotheses', full_name='rst.dialog.DialogAct.speech_hypotheses', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DIALOGACT_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=435,
)

_DIALOGACT.fields_by_name['type'].enum_type = _DIALOGACT_TYPE
_DIALOGACT.fields_by_name['incremental_unit'].message_type = rst_dot_dialog_dot_IncrementalUnit__pb2._INCREMENTALUNIT
_DIALOGACT.fields_by_name['speech_hypotheses'].message_type = rst_dot_dialog_dot_SpeechHypotheses__pb2._SPEECHHYPOTHESES
_DIALOGACT_TYPE.containing_type = _DIALOGACT
DESCRIPTOR.message_types_by_name['DialogAct'] = _DIALOGACT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DialogAct = _reflection.GeneratedProtocolMessageType('DialogAct', (_message.Message,), dict(
  DESCRIPTOR = _DIALOGACT,
  __module__ = 'rst.dialog.DialogAct_pb2'
  # @@protoc_insertion_point(class_scope:rst.dialog.DialogAct)
  ))
_sym_db.RegisterMessage(DialogAct)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rDialogActType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/AugmentedPointCloud3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import PointCloud3DFloat_pb2 as rst_dot_geometry_dot_PointCloud3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/AugmentedPointCloud3DFloat.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n+rst/vision/AugmentedPointCloud3DFloat.proto\x12\nrst.vision\x1a$rst/geometry/PointCloud3DFloat.proto\"\xbc\x01\n\x1a\x41ugmentedPointCloud3DFloat\x12/\n\x06points\x18\x01 \x02(\x0b\x32\x1f.rst.geometry.PointCloud3DFloat\x12@\n\x08\x63hannels\x18\x02 \x03(\x0b\x32..rst.vision.AugmentedPointCloud3DFloat.Channel\x1a+\n\x07\x43hannel\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x12\n\x06values\x18\x02 \x03(\x02\x42\x02\x10\x01\x42 B\x1e\x41ugmentedPointCloud3DFloatType')
  ,
  dependencies=[rst_dot_geometry_dot_PointCloud3DFloat__pb2.DESCRIPTOR,])




_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL = _descriptor.Descriptor(
  name='Channel',
  full_name='rst.vision.AugmentedPointCloud3DFloat.Channel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.vision.AugmentedPointCloud3DFloat.Channel.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='rst.vision.AugmentedPointCloud3DFloat.Channel.values', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=286,
)

_AUGMENTEDPOINTCLOUD3DFLOAT = _descriptor.Descriptor(
  name='AugmentedPointCloud3DFloat',
  full_name='rst.vision.AugmentedPointCloud3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='rst.vision.AugmentedPointCloud3DFloat.points', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='rst.vision.AugmentedPointCloud3DFloat.channels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=286,
)

_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL.containing_type = _AUGMENTEDPOINTCLOUD3DFLOAT
_AUGMENTEDPOINTCLOUD3DFLOAT.fields_by_name['points'].message_type = rst_dot_geometry_dot_PointCloud3DFloat__pb2._POINTCLOUD3DFLOAT
_AUGMENTEDPOINTCLOUD3DFLOAT.fields_by_name['channels'].message_type = _AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL
DESCRIPTOR.message_types_by_name['AugmentedPointCloud3DFloat'] = _AUGMENTEDPOINTCLOUD3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AugmentedPointCloud3DFloat = _reflection.GeneratedProtocolMessageType('AugmentedPointCloud3DFloat', (_message.Message,), dict(

  Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), dict(
    DESCRIPTOR = _AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL,
    __module__ = 'rst.vision.AugmentedPointCloud3DFloat_pb2'
    # @@protoc_insertion_point(class_scope:rst.vision.AugmentedPointCloud3DFloat.Channel)
    ))
  ,
  DESCRIPTOR = _AUGMENTEDPOINTCLOUD3DFLOAT,
  __module__ = 'rst.vision.AugmentedPointCloud3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.AugmentedPointCloud3DFloat)
  ))
_sym_db.RegisterMessage(AugmentedPointCloud3DFloat)
_sym_db.RegisterMessage(AugmentedPointCloud3DFloat.Channel)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\036AugmentedPointCloud3DFloatType'))
_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL.fields_by_name['values'].has_options = True
_AUGMENTEDPOINTCLOUD3DFLOAT_CHANNEL.fields_by_name['values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/Wrench.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.dynamics import Forces_pb2 as rst_dot_dynamics_dot_Forces__pb2
from rst.dynamics import Torques_pb2 as rst_dot_dynamics_dot_Torques__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/Wrench.proto',
  package='rst.dynamics',
  syntax='proto2',
  serialized_pb=_b('\n\x19rst/dynamics/Wrench.proto\x12\x0crst.dynamics\x1a\x19rst/dynamics/Forces.proto\x1a\x1arst/dynamics/Torques.proto\"V\n\x06Wrench\x12$\n\x06\x66orces\x18\x01 \x02(\x0b\x32\x14.rst.dynamics.Forces\x12&\n\x07torques\x18\x02 \x02(\x0b\x32\x15.rst.dynamics.TorquesB\x0c\x42\nWrenchType')
  ,
  dependencies=[rst_dot_dynamics_dot_Forces__pb2.DESCRIPTOR,rst_dot_dynamics_dot_Torques__pb2.DESCRIPTOR,])




_WRENCH = _descriptor.Descriptor(
  name='Wrench',
  full_name='rst.dynamics.Wrench',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='forces', full_name='rst.dynamics.Wrench.forces', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='torques', full_name='rst.dynamics.Wrench.torques', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=184,
)

_WRENCH.fields_by_name['forces'].message_type = rst_dot_dynamics_dot_Forces__pb2._FORCES
_WRENCH.fields_by_name['torques'].message_type = rst_dot_dynamics_dot_Torques__pb2._TORQUES
DESCRIPTOR.message_types_by_name['Wrench'] = _WRENCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Wrench = _reflection.GeneratedProtocolMessageType('Wrench', (_message.Message,), dict(
  DESCRIPTOR = _WRENCH,
  __module__ = 'rst.dynamics.Wrench_pb2'
  # @@protoc_insertion_point(class_scope:rst.dynamics.Wrench)
  ))
_sym_db.RegisterMessage(Wrench)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\nWrenchType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/FaceLandmarksCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import FaceLandmarks_pb2 as rst_dot_vision_dot_FaceLandmarks__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/FaceLandmarksCollection.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n(rst/vision/FaceLandmarksCollection.proto\x12\nrst.vision\x1a\x1erst/vision/FaceLandmarks.proto\"E\n\x17\x46\x61\x63\x65LandmarksCollection\x12*\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x19.rst.vision.FaceLandmarksB\x1d\x42\x1b\x46\x61\x63\x65LandmarksCollectionType')
  ,
  dependencies=[rst_dot_vision_dot_FaceLandmarks__pb2.DESCRIPTOR,])




_FACELANDMARKSCOLLECTION = _descriptor.Descriptor(
  name='FaceLandmarksCollection',
  full_name='rst.vision.FaceLandmarksCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.vision.FaceLandmarksCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=157,
)

_FACELANDMARKSCOLLECTION.fields_by_name['element'].message_type = rst_dot_vision_dot_FaceLandmarks__pb2._FACELANDMARKS
DESCRIPTOR.message_types_by_name['FaceLandmarksCollection'] = _FACELANDMARKSCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceLandmarksCollection = _reflection.GeneratedProtocolMessageType('FaceLandmarksCollection', (_message.Message,), dict(
  DESCRIPTOR = _FACELANDMARKSCOLLECTION,
  __module__ = 'rst.vision.FaceLandmarksCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.FaceLandmarksCollection)
  ))
_sym_db.RegisterMessage(FaceLandmarksCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033FaceLandmarksCollectionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/CpuState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/CpuState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n\"rst/devices/generic/CpuState.proto\x12\x13rst.devices.generic\"\xb2\x02\n\x08\x43puState\x12\x14\n\x0cjiffy_length\x18\n \x01(\r\x12/\n\x04\x63pus\x18\x14 \x03(\x0b\x32!.rst.devices.generic.CpuState.Cpu\x12\x0e\n\x06load_1\x18( \x01(\x02\x12\x0e\n\x06load_5\x18) \x01(\x02\x12\x0f\n\x07load_15\x18* \x01(\x02\x1a\xad\x01\n\x03\x43pu\x12\r\n\x05index\x18\x01 \x02(\x05\x12\r\n\x05total\x18\x64 \x02(\x04\x12\x0c\n\x04idle\x18\x05 \x02(\x04\x12\x0c\n\x04user\x18\x02 \x01(\x04\x12\x10\n\x08user_low\x18\x03 \x01(\x04\x12\x0e\n\x06system\x18\x04 \x01(\x04\x12\x0e\n\x06iowait\x18\x06 \x01(\x04\x12\x0b\n\x03irq\x18\x07 \x01(\x04\x12\x0f\n\x07softirq\x18\x08 \x01(\x04\x12\r\n\x05steal\x18\t \x01(\x04\x12\r\n\x05guest\x18\n \x01(\x04\x42\x0e\x42\x0c\x43puStateType')
)




_CPUSTATE_CPU = _descriptor.Descriptor(
  name='Cpu',
  full_name='rst.devices.generic.CpuState.Cpu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='rst.devices.generic.CpuState.Cpu.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total', full_name='rst.devices.generic.CpuState.Cpu.total', index=1,
      number=100, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='idle', full_name='rst.devices.generic.CpuState.Cpu.idle', index=2,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user', full_name='rst.devices.generic.CpuState.Cpu.user', index=3,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_low', full_name='rst.devices.generic.CpuState.Cpu.user_low', index=4,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='system', full_name='rst.devices.generic.CpuState.Cpu.system', index=5,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='iowait', full_name='rst.devices.generic.CpuState.Cpu.iowait', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='irq', full_name='rst.devices.generic.CpuState.Cpu.irq', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='softirq', full_name='rst.devices.generic.CpuState.Cpu.softirq', index=8,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steal', full_name='rst.devices.generic.CpuState.Cpu.steal', index=9,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guest', full_name='rst.devices.generic.CpuState.Cpu.guest', index=10,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=366,
)

_CPUSTATE = _descriptor.Descriptor(
  name='CpuState',
  full_name='rst.devices.generic.CpuState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jiffy_length', full_name='rst.devices.generic.CpuState.jiffy_length', index=0,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpus', full_name='rst.devices.generic.CpuState.cpus', index=1,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_1', full_name='rst.devices.generic.CpuState.load_1', index=2,
      number=40, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_5', full_name='rst.devices.generic.CpuState.load_5', index=3,
      number=41, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_15', full_name='rst.devices.generic.CpuState.load_15', index=4,
      number=42, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CPUSTATE_CPU, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=366,
)

_CPUSTATE_CPU.containing_type = _CPUSTATE
_CPUSTATE.fields_by_name['cpus'].message_type = _CPUSTATE_CPU
DESCRIPTOR.message_types_by_name['CpuState'] = _CPUSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CpuState = _reflection.GeneratedProtocolMessageType('CpuState', (_message.Message,), dict(

  Cpu = _reflection.GeneratedProtocolMessageType('Cpu', (_message.Message,), dict(
    DESCRIPTOR = _CPUSTATE_CPU,
    __module__ = 'rst.devices.generic.CpuState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.CpuState.Cpu)
    ))
  ,
  DESCRIPTOR = _CPUSTATE,
  __module__ = 'rst.devices.generic.CpuState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.CpuState)
  ))
_sym_db.RegisterMessage(CpuState)
_sym_db.RegisterMessage(CpuState.Cpu)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014CpuStateType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/TriangleMesh3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import PointCloud3DFloat_pb2 as rst_dot_geometry_dot_PointCloud3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/TriangleMesh3DFloat.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n&rst/geometry/TriangleMesh3DFloat.proto\x12\x0crst.geometry\x1a$rst/geometry/PointCloud3DFloat.proto\"\xc3\x01\n\x13TriangleMesh3DFloat\x12\x31\n\x08vertices\x18\x01 \x02(\x0b\x32\x1f.rst.geometry.PointCloud3DFloat\x12=\n\ttriangles\x18\x02 \x03(\x0b\x32*.rst.geometry.TriangleMesh3DFloat.Triangle\x1a:\n\x08Triangle\x12\x0e\n\x06point1\x18\x01 \x02(\r\x12\x0e\n\x06point2\x18\x02 \x02(\r\x12\x0e\n\x06point3\x18\x03 \x02(\rB\x19\x42\x17TriangleMesh3DFloatType')
  ,
  dependencies=[rst_dot_geometry_dot_PointCloud3DFloat__pb2.DESCRIPTOR,])




_TRIANGLEMESH3DFLOAT_TRIANGLE = _descriptor.Descriptor(
  name='Triangle',
  full_name='rst.geometry.TriangleMesh3DFloat.Triangle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point1', full_name='rst.geometry.TriangleMesh3DFloat.Triangle.point1', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='point2', full_name='rst.geometry.TriangleMesh3DFloat.Triangle.point2', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='point3', full_name='rst.geometry.TriangleMesh3DFloat.Triangle.point3', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=290,
)

_TRIANGLEMESH3DFLOAT = _descriptor.Descriptor(
  name='TriangleMesh3DFloat',
  full_name='rst.geometry.TriangleMesh3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='rst.geometry.TriangleMesh3DFloat.vertices', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='triangles', full_name='rst.geometry.TriangleMesh3DFloat.triangles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_TRIANGLEMESH3DFLOAT_TRIANGLE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=290,
)

_TRIANGLEMESH3DFLOAT_TRIANGLE.containing_type = _TRIANGLEMESH3DFLOAT
_TRIANGLEMESH3DFLOAT.fields_by_name['vertices'].message_type = rst_dot_geometry_dot_PointCloud3DFloat__pb2._POINTCLOUD3DFLOAT
_TRIANGLEMESH3DFLOAT.fields_by_name['triangles'].message_type = _TRIANGLEMESH3DFLOAT_TRIANGLE
DESCRIPTOR.message_types_by_name['TriangleMesh3DFloat'] = _TRIANGLEMESH3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TriangleMesh3DFloat = _reflection.GeneratedProtocolMessageType('TriangleMesh3DFloat', (_message.Message,), dict(

  Triangle = _reflection.GeneratedProtocolMessageType('Triangle', (_message.Message,), dict(
    DESCRIPTOR = _TRIANGLEMESH3DFLOAT_TRIANGLE,
    __module__ = 'rst.geometry.TriangleMesh3DFloat_pb2'
    # @@protoc_insertion_point(class_scope:rst.geometry.TriangleMesh3DFloat.Triangle)
    ))
  ,
  DESCRIPTOR = _TRIANGLEMESH3DFLOAT,
  __module__ = 'rst.geometry.TriangleMesh3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.TriangleMesh3DFloat)
  ))
_sym_db.RegisterMessage(TriangleMesh3DFloat)
_sym_db.RegisterMessage(TriangleMesh3DFloat.Triangle)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\027TriangleMesh3DFloatType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/HostInformation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.devices.generic import MemoryState_pb2 as rst_dot_devices_dot_generic_dot_MemoryState__pb2
from rst.devices.generic import CpuState_pb2 as rst_dot_devices_dot_generic_dot_CpuState__pb2
from rst.devices.generic import DiskState_pb2 as rst_dot_devices_dot_generic_dot_DiskState__pb2
from rst.devices.generic import NetworkState_pb2 as rst_dot_devices_dot_generic_dot_NetworkState__pb2
from rst.devices.generic import UserState_pb2 as rst_dot_devices_dot_generic_dot_UserState__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/HostInformation.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n)rst/devices/generic/HostInformation.proto\x12\x13rst.devices.generic\x1a%rst/devices/generic/MemoryState.proto\x1a\"rst/devices/generic/CpuState.proto\x1a#rst/devices/generic/DiskState.proto\x1a&rst/devices/generic/NetworkState.proto\x1a#rst/devices/generic/UserState.proto\"\xc4\x02\n\x0fHostInformation\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x36\n\x0cmemory_state\x18\x02 \x01(\x0b\x32 .rst.devices.generic.MemoryState\x12\x30\n\tcpu_state\x18\x03 \x01(\x0b\x32\x1d.rst.devices.generic.CpuState\x12\x13\n\x0bprocess_num\x18\x04 \x01(\x04\x12\x32\n\ndisk_state\x18\x05 \x01(\x0b\x32\x1e.rst.devices.generic.DiskState\x12\x38\n\rnetwork_state\x18\x06 \x01(\x0b\x32!.rst.devices.generic.NetworkState\x12\x32\n\nuser_state\x18\x07 \x01(\x0b\x32\x1e.rst.devices.generic.UserStateB\x15\x42\x13HostInformationType')
  ,
  dependencies=[rst_dot_devices_dot_generic_dot_MemoryState__pb2.DESCRIPTOR,rst_dot_devices_dot_generic_dot_CpuState__pb2.DESCRIPTOR,rst_dot_devices_dot_generic_dot_DiskState__pb2.DESCRIPTOR,rst_dot_devices_dot_generic_dot_NetworkState__pb2.DESCRIPTOR,rst_dot_devices_dot_generic_dot_UserState__pb2.DESCRIPTOR,])




_HOSTINFORMATION = _descriptor.Descriptor(
  name='HostInformation',
  full_name='rst.devices.generic.HostInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hostname', full_name='rst.devices.generic.HostInformation.hostname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memory_state', full_name='rst.devices.generic.HostInformation.memory_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_state', full_name='rst.devices.generic.HostInformation.cpu_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_num', full_name='rst.devices.generic.HostInformation.process_num', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='disk_state', full_name='rst.devices.generic.HostInformation.disk_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='network_state', full_name='rst.devices.generic.HostInformation.network_state', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_state', full_name='rst.devices.generic.HostInformation.user_state', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=580,
)

_HOSTINFORMATION.fields_by_name['memory_state'].message_type = rst_dot_devices_dot_generic_dot_MemoryState__pb2._MEMORYSTATE
_HOSTINFORMATION.fields_by_name['cpu_state'].message_type = rst_dot_devices_dot_generic_dot_CpuState__pb2._CPUSTATE
_HOSTINFORMATION.fields_by_name['disk_state'].message_type = rst_dot_devices_dot_generic_dot_DiskState__pb2._DISKSTATE
_HOSTINFORMATION.fields_by_name['network_state'].message_type = rst_dot_devices_dot_generic_dot_NetworkState__pb2._NETWORKSTATE
_HOSTINFORMATION.fields_by_name['user_state'].message_type = rst_dot_devices_dot_generic_dot_UserState__pb2._USERSTATE
DESCRIPTOR.message_types_by_name['HostInformation'] = _HOSTINFORMATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HostInformation = _reflection.GeneratedProtocolMessageType('HostInformation', (_message.Message,), dict(
  DESCRIPTOR = _HOSTINFORMATION,
  __module__ = 'rst.devices.generic.HostInformation_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.HostInformation)
  ))
_sym_db.RegisterMessage(HostInformation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023HostInformationType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/RecurrenceId.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/RecurrenceId.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1frst/calendar/RecurrenceId.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\"\x85\x02\n\x0cRecurrenceId\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32\x1f.rst.calendar.RecurrenceId.Type:\tDATE_TIME\x12\x37\n\x05range\x18\x02 \x01(\x0e\x32 .rst.calendar.RecurrenceId.Range:\x06SINGLE\x12#\n\x03rid\x18\x03 \x01(\x0b\x32\x16.rst.calendar.DateTime\"\x1f\n\x04Type\x12\r\n\tDATE_TIME\x10\x01\x12\x08\n\x04\x44\x41TE\x10\x02\"<\n\x05Range\x12\n\n\x06SINGLE\x10\x01\x12\x13\n\x0fTHIS_AND_FUTURE\x10\x02\x12\x12\n\x0eTHIS_AND_PRIOR\x10\x03\x42\x12\x42\x10RecurrenceIdType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,])



_RECURRENCEID_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.calendar.RecurrenceId.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATE_TIME', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=247,
  serialized_end=278,
)
_sym_db.RegisterEnumDescriptor(_RECURRENCEID_TYPE)

_RECURRENCEID_RANGE = _descriptor.EnumDescriptor(
  name='Range',
  full_name='rst.calendar.RecurrenceId.Range',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIS_AND_FUTURE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIS_AND_PRIOR', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=280,
  serialized_end=340,
)
_sym_db.RegisterEnumDescriptor(_RECURRENCEID_RANGE)


_RECURRENCEID = _descriptor.Descriptor(
  name='RecurrenceId',
  full_name='rst.calendar.RecurrenceId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.calendar.RecurrenceId.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='range', full_name='rst.calendar.RecurrenceId.range', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rid', full_name='rst.calendar.RecurrenceId.rid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECURRENCEID_TYPE,
    _RECURRENCEID_RANGE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=340,
)

_RECURRENCEID.fields_by_name['type'].enum_type = _RECURRENCEID_TYPE
_RECURRENCEID.fields_by_name['range'].enum_type = _RECURRENCEID_RANGE
_RECURRENCEID.fields_by_name['rid'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_RECURRENCEID_TYPE.containing_type = _RECURRENCEID
_RECURRENCEID_RANGE.containing_type = _RECURRENCEID
DESCRIPTOR.message_types_by_name['RecurrenceId'] = _RECURRENCEID
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecurrenceId = _reflection.GeneratedProtocolMessageType('RecurrenceId', (_message.Message,), dict(
  DESCRIPTOR = _RECURRENCEID,
  __module__ = 'rst.calendar.RecurrenceId_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.RecurrenceId)
  ))
_sym_db.RegisterMessage(RecurrenceId)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020RecurrenceIdType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/animation/HeadAnimation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/animation/HeadAnimation.proto',
  package='rst.animation',
  syntax='proto2',
  serialized_pb=_b('\n!rst/animation/HeadAnimation.proto\x12\rrst.animation\"\xd7\x02\n\rHeadAnimation\x12\x39\n\tanimation\x18\x01 \x02(\x0e\x32&.rst.animation.HeadAnimation.Animation\x12\x16\n\x0brepetitions\x18\x02 \x02(\r:\x01\x31\x12\x15\n\rduration_each\x18\x03 \x02(\r\x12\x19\n\x0e\x65mphasis_scale\x18\x04 \x02(\x02:\x01\x31\"\xc0\x01\n\tAnimation\x12\x08\n\x04IDLE\x10\x00\x12\x0c\n\x08HEAD_NOD\x10\x01\x12\x0e\n\nHEAD_SHAKE\x10\x02\x12\x11\n\rEYEBLINK_LEFT\x10\x03\x12\x12\n\x0e\x45YEBLINK_RIGHT\x10\x04\x12\x11\n\rEYEBLINK_BOTH\x10\x05\x12\x12\n\x0e\x45YEBROWS_RAISE\x10\x06\x12\x12\n\x0e\x45YEBROWS_LOWER\x10\x07\x12\x13\n\x0f\x45NGAGEMENT_LEFT\x10\x08\x12\x14\n\x10\x45NGAGEMENT_RIGHT\x10\tB\x13\x42\x11HeadAnimationType')
)



_HEADANIMATION_ANIMATION = _descriptor.EnumDescriptor(
  name='Animation',
  full_name='rst.animation.HeadAnimation.Animation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IDLE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEAD_NOD', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEAD_SHAKE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBLINK_LEFT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBLINK_RIGHT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBLINK_BOTH', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBROWS_RAISE', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EYEBROWS_LOWER', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENGAGEMENT_LEFT', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENGAGEMENT_RIGHT', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=204,
  serialized_end=396,
)
_sym_db.RegisterEnumDescriptor(_HEADANIMATION_ANIMATION)


_HEADANIMATION = _descriptor.Descriptor(
  name='HeadAnimation',
  full_name='rst.animation.HeadAnimation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='animation', full_name='rst.animation.HeadAnimation.animation', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='repetitions', full_name='rst.animation.HeadAnimation.repetitions', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration_each', full_name='rst.animation.HeadAnimation.duration_each', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='emphasis_scale', full_name='rst.animation.HeadAnimation.emphasis_scale', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEADANIMATION_ANIMATION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=396,
)

_HEADANIMATION.fields_by_name['animation'].enum_type = _HEADANIMATION_ANIMATION
_HEADANIMATION_ANIMATION.containing_type = _HEADANIMATION
DESCRIPTOR.message_types_by_name['HeadAnimation'] = _HEADANIMATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HeadAnimation = _reflection.GeneratedProtocolMessageType('HeadAnimation', (_message.Message,), dict(
  DESCRIPTOR = _HEADANIMATION,
  __module__ = 'rst.animation.HeadAnimation_pb2'
  # @@protoc_insertion_point(class_scope:rst.animation.HeadAnimation)
  ))
_sym_db.RegisterMessage(HeadAnimation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021HeadAnimationType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/PointCloud2DIntCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import PointCloud2DInt_pb2 as rst_dot_geometry_dot_PointCloud2DInt__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/PointCloud2DIntCollection.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n,rst/geometry/PointCloud2DIntCollection.proto\x12\x0crst.geometry\x1a\"rst/geometry/PointCloud2DInt.proto\"K\n\x19PointCloud2DIntCollection\x12.\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1d.rst.geometry.PointCloud2DIntB\x1f\x42\x1dPointCloud2DIntCollectionType')
  ,
  dependencies=[rst_dot_geometry_dot_PointCloud2DInt__pb2.DESCRIPTOR,])




_POINTCLOUD2DINTCOLLECTION = _descriptor.Descriptor(
  name='PointCloud2DIntCollection',
  full_name='rst.geometry.PointCloud2DIntCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.PointCloud2DIntCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=173,
)

_POINTCLOUD2DINTCOLLECTION.fields_by_name['element'].message_type = rst_dot_geometry_dot_PointCloud2DInt__pb2._POINTCLOUD2DINT
DESCRIPTOR.message_types_by_name['PointCloud2DIntCollection'] = _POINTCLOUD2DINTCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointCloud2DIntCollection = _reflection.GeneratedProtocolMessageType('PointCloud2DIntCollection', (_message.Message,), dict(
  DESCRIPTOR = _POINTCLOUD2DINTCOLLECTION,
  __module__ = 'rst.geometry.PointCloud2DIntCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.PointCloud2DIntCollection)
  ))
_sym_db.RegisterMessage(PointCloud2DIntCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\035PointCloud2DIntCollectionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/animation/BinocularHeadGaze.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import SphericalDirectionFloat_pb2 as rst_dot_geometry_dot_SphericalDirectionFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/animation/BinocularHeadGaze.proto',
  package='rst.animation',
  syntax='proto2',
  serialized_pb=_b('\n%rst/animation/BinocularHeadGaze.proto\x12\rrst.animation\x1a*rst/geometry/SphericalDirectionFloat.proto\"\x9a\x01\n\x11\x42inocularHeadGaze\x12\x35\n\x06target\x18\x01 \x02(\x0b\x32%.rst.geometry.SphericalDirectionFloat\x12\x17\n\x0c\x65ye_vergence\x18\x02 \x02(\x02:\x01\x30\x12\x35\n\x06offset\x18\x03 \x02(\x0b\x32%.rst.geometry.SphericalDirectionFloatB\x17\x42\x15\x42inocularHeadGazeType')
  ,
  dependencies=[rst_dot_geometry_dot_SphericalDirectionFloat__pb2.DESCRIPTOR,])




_BINOCULARHEADGAZE = _descriptor.Descriptor(
  name='BinocularHeadGaze',
  full_name='rst.animation.BinocularHeadGaze',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='rst.animation.BinocularHeadGaze.target', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eye_vergence', full_name='rst.animation.BinocularHeadGaze.eye_vergence', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='rst.animation.BinocularHeadGaze.offset', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=255,
)

_BINOCULARHEADGAZE.fields_by_name['target'].message_type = rst_dot_geometry_dot_SphericalDirectionFloat__pb2._SPHERICALDIRECTIONFLOAT
_BINOCULARHEADGAZE.fields_by_name['offset'].message_type = rst_dot_geometry_dot_SphericalDirectionFloat__pb2._SPHERICALDIRECTIONFLOAT
DESCRIPTOR.message_types_by_name['BinocularHeadGaze'] = _BINOCULARHEADGAZE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BinocularHeadGaze = _reflection.GeneratedProtocolMessageType('BinocularHeadGaze', (_message.Message,), dict(
  DESCRIPTOR = _BINOCULARHEADGAZE,
  __module__ = 'rst.animation.BinocularHeadGaze_pb2'
  # @@protoc_insertion_point(class_scope:rst.animation.BinocularHeadGaze)
  ))
_sym_db.RegisterMessage(BinocularHeadGaze)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\025BinocularHeadGazeType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/BoundingBox.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.math import Vec2DInt_pb2 as rst_dot_math_dot_Vec2DInt__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/BoundingBox.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/geometry/BoundingBox.proto\x12\x0crst.geometry\x1a\x17rst/math/Vec2DInt.proto\"}\n\x0b\x42oundingBox\x12$\n\x08top_left\x18\x01 \x02(\x0b\x32\x12.rst.math.Vec2DInt\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\r\x12\x13\n\x0bimage_width\x18\x04 \x01(\r\x12\x14\n\x0cimage_height\x18\x05 \x01(\rB\x11\x42\x0f\x42oundingBoxType')
  ,
  dependencies=[rst_dot_math_dot_Vec2DInt__pb2.DESCRIPTOR,])




_BOUNDINGBOX = _descriptor.Descriptor(
  name='BoundingBox',
  full_name='rst.geometry.BoundingBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_left', full_name='rst.geometry.BoundingBox.top_left', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.geometry.BoundingBox.width', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.geometry.BoundingBox.height', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_width', full_name='rst.geometry.BoundingBox.image_width', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_height', full_name='rst.geometry.BoundingBox.image_height', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=198,
)

_BOUNDINGBOX.fields_by_name['top_left'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
DESCRIPTOR.message_types_by_name['BoundingBox'] = _BOUNDINGBOX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundingBox = _reflection.GeneratedProtocolMessageType('BoundingBox', (_message.Message,), dict(
  DESCRIPTOR = _BOUNDINGBOX,
  __module__ = 'rst.geometry.BoundingBox_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.BoundingBox)
  ))
_sym_db.RegisterMessage(BoundingBox)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017BoundingBoxType'))
# @@protoc_insertion_point(module_scope)
